# Структура документа из структуры каталогов

Главная и первоочередная задача, которая стояла при разработке этого
инструмента:

1. Возможность собрать итоговый один документы word/pdf/epub/markdown/latex
   из исходников в формате Markdown;
2. Итоговый документ должен иметь структуру заголовков, повторяющую структуру
   каталогов, в которых хранятся исходники.

Формат Markdown в качестве исходника был выбран по причине его простоты,
распространенности и гибкости.
